jsTree v.1.0 - unique documentation

# jsTree v.1.0

# unique plugin

## Description

The `unique` plugin prevents from nodes with same titles coexisting (create/move/rename) in the same parent.

## Configuration

### error_callback

A function. Default is `$.noop`.

Whenever the plugin stops an action (because it violates the unique policy) this function will bre triggered in current tree's scope, receiving the name, siblings and function name that caused the conflict.

## Demos

Try moving the child nodes together (drag'n'drop).

### Using the unique plugin

- Root node 1
  - Child node 1
- Root node 2
  - Child node 1

## API

### ._check_unique ( names, siblings )

Used internally - checks the names array against the sibling nodes for matches.